<?php
/**
 * Slovaklanguage file
 *
 * @author Michal Mesko <michal.mesko@gmail.com>
 * @author exusik@gmail.com
 * @author Martin Michalek <michalek.dev@gmail.com>
 */
$lang['menu']                  = 'Reverzný manažér';
$lang['filter']                = 'Hľadať spamerské stránky';
$lang['revert']                = 'Vrátiť vybrané stránky';
$lang['reverted']              = '%s vrátená na revíziu %s';
$lang['removed']               = '%s odstránená';
$lang['revstart']              = 'Proces reverzie bol spustený. Toto môže trvať dlhý čas. Ak skript prekročí daný maximálny časový interval pred tým, ako skončí, musíte urobiť reverziu v menších dávkach.';
$lang['revstop']               = 'Proces reverzie sa úspešne skončil.';
$lang['note1']                 = 'Poznámka: vyhľadávanie rozlišuje medzi veľkými a malými písmenami';
$lang['note2']                 = 'Poznámka: táto stránka bude vrátená do poslednej verzie, ktorá neobsahuje spamový výraz <i>%s</i>.';
